==> 1.0.0.tar.gz: lib/src/magic_method_channel.dart <==
import 'package:flutter/services.dart';
import 'package:magic_flutter/src/magic_platform_interface.dart';
import 'package:magic_flutter/src/model/generate_id_token_model.dart';
import 'package:magic_flutter/src/model/get_id_token_model.dart';
import 'package:magic_flutter/src/model/get_metadata_response_model.dart';

class MagicMethodChannel extends MagicPlatformInterface {
  static const MethodChannel _methodChannel = MethodChannel('magic');

  @override
  Future<GenerateIdTokenResponse> generateIdToken() {
    throw UnimplementedError();
  }

  @override
  Future<GetIdTokenResponse> getIdToken() {
    throw UnimplementedError();
  }

  @override
  Future<GetMetaDataResponse> getMetaData() async {
    return GetMetaDataResponse.fromJson(
        await _methodChannel.invokeMapMethod<String, dynamic>('getMetaData') ??
            <String, dynamic>{});
  }

  @override
  Future<bool> isLoggedIn() async {
    final result = await _methodChannel.invokeMethod("isLoggedIn") as bool;
    return result;
  }

  @override
  Future<String> loginWithMagicLink({required String email}) async {
    // final result = await _methodChannel.invokeMapMethod<String, dynamic>(
    //         'loginWithMagicLink', email) ??
    //     <String, dynamic>{};
    // return DidToken.fromJson(result);
    final result =
        await _methodChannel.invokeMethod('loginWithMagicLink', email) as String;
    return result;
  }

  @override
  Future<bool> logout() async {
    final result = await _methodChannel.invokeMethod('logout') as bool;
    return result;
  }

  @override
  Future<bool> updateEmail({required String email}) async {
    final result =
        await _methodChannel.invokeMethod('updateEmail', email) as bool;
    return result;
  }

  @override
  Future<String> sendTransaction(
      {required String fromAccount,
      required String toAccount,
      required String transactionAmount,
      String? gasPriceAmount,
      String? gasLimitAmount}) async {
    Map data = {
      "from": fromAccount,
      "to": toAccount,
      "amount": transactionAmount,
      "gasPrice": gasPriceAmount,
      "gasLimit": gasLimitAmount
    };
    final result = await _methodChannel.invokeMethod('sendTransaction', data);
    return result;
  }

  @override
  Future<String> getAccount() async {
    final result = await _methodChannel.invokeMethod('getAccount');
    return result;
  }

  @override
  Future<String> getUserBalance({required String accountAddress}) async {
    final result =
        await _methodChannel.invokeMethod('getUserBalance', accountAddress);
    return result;
  }


  @override
  Future<bool> initializeMagic(
      {required String publisherKey, String? chainId, String? rpcUrl}) async {
    Map data = {
      "publisherKey": publisherKey,
      "chainId": chainId,
      "rpcUrl": rpcUrl
    };
    return await _methodChannel.invokeMethod('initializeMagic', data) as bool;
  }
}

==> 1.0.5.tar.gz: lib/src/magic_method_channel.dart <==
import 'package:flutter/services.dart';
import 'package:magic_flutter/src/magic_platform_interface.dart';
import 'package:magic_flutter/src/model/generate_id_token_model.dart';
import 'package:magic_flutter/src/model/get_id_token_model.dart';
import 'package:magic_flutter/src/model/get_metadata_response_model.dart';

class MagicMethodChannel extends MagicPlatformInterface {
  static const MethodChannel _methodChannel = MethodChannel('magic');

  @override
  Future<GenerateIdTokenResponse> generateIdToken() {
    throw UnimplementedError();
  }

  @override
  Future<GetIdTokenResponse> getIdToken() {
    throw UnimplementedError();
  }

  @override
  Future<GetMetaDataResponse> getMetaData() async {
    return GetMetaDataResponse.fromJson(
        await _methodChannel.invokeMapMethod<String, dynamic>('getMetaData') ??
            <String, dynamic>{});
  }

  @override
  Future<bool> isLoggedIn() async {
    final result = await _methodChannel.invokeMethod("isLoggedIn") as bool;
    return result;
  }

  @override
  Future<String> loginWithMagicLink(
      {required String email, required bool showUI}) async {
    // final result = await _methodChannel.invokeMapMethod<String, dynamic>(
    //         'loginWithMagicLink', email) ??
    //     <String, dynamic>{};
    // return DidToken.fromJson(result);
    Map data = {"email": email, "showUI": showUI};
    final result =
        await _methodChannel.invokeMethod('loginWithMagicLink', data) as String;
    return result;
  }

  @override
  Future<bool> logout() async {
    final result = await _methodChannel.invokeMethod('logout') as bool;
    return result;
  }

  @override
  Future<bool> updateEmail({required String email}) async {
    final result =
        await _methodChannel.invokeMethod('updateEmail', email) as bool;
    return result;
  }

  @override
  Future<String> sendTransaction(
      {required String fromAccount,
      required String toAccount,
      required String transactionAmount,
      String? gasPriceAmount,
      String? gasLimitAmount}) async {
    Map data = {
      "from": fromAccount,
      "to": toAccount,
      "amount": transactionAmount,
      "gasPrice": gasPriceAmount,
      "gasLimit": gasLimitAmount
    };
    final result = await _methodChannel.invokeMethod('sendTransaction', data);
    return result;
  }

  @override
  Future<String> sendDynamicContractTransaction(
      {required String fromAccount,
      required String toAccount,
      required String transactionAmount,
      String? contractABI,
      required String contractAddress,
      required String gasPriceAmount,
      required String gasLimitAmount}) async {
    Map data = {
      "from": fromAccount,
      "to": toAccount,
      "amount": transactionAmount,
      "contractABI": contractABI,
      "contractAddress": contractAddress,
      "gasPrice": gasPriceAmount,
      "gasLimit": gasLimitAmount
    };
    final result = await _methodChannel.invokeMethod(
        'sendDynamicContractTransaction', data);
    return result;
  }

  @override
  Future<String> getDynamicContractUserBalance(
      {required String accountAddress,
      String? contractABI,
      required String contractAddress}) async {
    Map data = {
      "contractABI": contractABI,
      "contractAddress": contractAddress,
      "accountAddress": accountAddress,
    };

    final result = await _methodChannel.invokeMethod(
        'getDynamicContractUserBalance', data);
    return result;
  }

  @override
  Future<String> getAccount() async {
    final result = await _methodChannel.invokeMethod('getAccount');
    return result;
  }

  @override
  Future<String> getUserBalance({required String accountAddress}) async {
    final result =
        await _methodChannel.invokeMethod('getUserBalance', accountAddress);
    return result;
  }

  @override
  Future<bool> initializeMagic(
      {required String publisherKey, String? chainId, String? rpcUrl}) async {
    Map data = {
      "publisherKey": publisherKey,
      "chainId": chainId,
      "rpcUrl": rpcUrl
    };
    return await _methodChannel.invokeMethod('initializeMagic', data) as bool;
  }
}
